@@ -129,7 +129,9 @@ function initLevel() {
         if(levelData.levels[i].type === undefined) {
             items.availablePieces.model.append( {
                 "imgName": levelData.levels[i].pixmapfile,
-                "imgSound": levelData.levels[i].sound ? levelData.levels[i].sound : "",
+                "imgSound": levelData.levels[i].soundFile ?
+                     soundsUrl + levelData.levels[i].soundFile :
+                     "qrc:/gcompris/src/core/resource/sounds/scroll.wav",
                 "imgHeight": levelData.levels[i].height == undefined ? 0 : levelData.levels[i].height,
                 "imgWidth": levelData.levels[i].width == undefined ? 0 : levelData.levels[i].width,
                 "toolTipText":
@@ -139,8 +141,6 @@ function initLevel() {
                                                        (levelData.levels[i].toolTipText.split('|').length > 1 ?
                                                         levelData.levels[i].toolTipText.split('|')[1] :
                                                         levelData.levels[i].toolTipText),
-                "pressSound": levelData.levels[i].soundFile == undefined ? 
-							  "qrc:/gcompris/src/core/resource/sounds/bleep.wav" : soundsUrl + levelData.levels[i].soundFile
             });
 
             spots[j++] = dropItemComponent.createObject(
