@@ -80,7 +80,8 @@ function validateLevels(levels)
 function loadLevels()
 {
     var ret;
-    var filename = GCompris.ApplicationInfo.getLocaleFilePath(url + "levels-$LOCALE.json");
+    var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
+    var filename = GCompris.ApplicationInfo.getLocaleFilePath(url + "levels-" + locale + ".json");
     levels = items.parser.parseFromUrl(filename);
     if (levels == null) {
         console.warn("Click_on_letter: Invalid levels file " + filename);
