@@ -101,40 +101,17 @@ function stop() {
 
 function initLevel() {
     items.bar.level = currentLevel + 1
+    items.background.startedHelp = false
 
     setUp()
 }
 
 function setUp() {
-    if (items.notShowed === true) {
-        items.notShowed = false
-    }
-    else hideProblem()
-
     loadCoordinate()
 
-    for (var i=0;i<items.model.length;i++) {
-        items.img1.repeater.itemAt(i).opacity = items.img1.show ? 1 : 0
-        items.img2.repeater.itemAt(i).opacity = items.img2.show ? 1 : 0
-
-        items.img1.repeater.itemAt(i).source = url + "photo" + (currentLevel+1) + "_" + (i+1) + ".svg"
-        items.img2.repeater.itemAt(i).source = url + "photo" + (currentLevel+1) + "_" + (i+1) + ".svg"
-
-        items.img1.repeater.itemAt(i).sourceSize.width = dataset[currentLevel].coordinates[i].r * 200
-        items.img1.repeater.itemAt(i).sourceSize.height = dataset[currentLevel].coordinates[i].r * 200
-
-        items.img2.repeater.itemAt(i).sourceSize.width = dataset[currentLevel].coordinates[i].r * 200
-        items.img2.repeater.itemAt(i).sourceSize.height = dataset[currentLevel].coordinates[i].r * 200
-
-        items.img1.repeater.itemAt(i).widthScale = dataset[currentLevel].coordinates[i].w
-        items.img1.repeater.itemAt(i).heightScale = dataset[currentLevel].coordinates[i].h
-
-        items.img2.repeater.itemAt(i).widthScale = dataset[currentLevel].coordinates[i].w
-        items.img2.repeater.itemAt(i).heightScale = dataset[currentLevel].coordinates[i].h
-
+    for (var i = 0; i < items.model.length; i++) {
         items.img1.circleRepeater.itemAt(i).opacity = 0
         items.img2.circleRepeater.itemAt(i).opacity = 0
-
     }
 
     items.img1.good = 0
@@ -160,7 +137,7 @@ function loadCoordinate() {
 }
 
 
-function photoClicked(item,index) {
+function photoClicked(item, index) {
     //only if the difference is not yet spotted
     if (items.img2.repeater.itemAt(index).opacity === 0) {
 
@@ -187,13 +164,12 @@ function photoClicked(item,index) {
 
 function hideProblem() {
     items.frame.anchors.top = items.background.top
-    items.problem.problemText.opacity = 0
-    items.problem.problemText.height = 0
-    items.problem.opacity = 0
+    items.frame.problemTextHeight = 0
+    items.problem.z = -5
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel ) {
+    if(numberOfLevel <= ++currentLevel) {
         currentLevel = 0
     }
     initLevel();
