@@ -47,7 +47,7 @@ var dataset = [
             {
                 "columns": 4,
                 "image":
-                [
+                    [
                     2,0,0,0,
                     0,1,0,0,
                     0,0,1,0,
@@ -58,7 +58,7 @@ var dataset = [
             {
                 "columns": 4,
                 "image":
-                [
+                    [
                     1,1,0,0,
                     0,2,2,0,
                     0,0,1,1,
@@ -69,7 +69,7 @@ var dataset = [
             {
                 "columns": 4,
                 "image":
-                [
+                    [
                     1,0,0,0,
                     0,1,0,0,
                     0,0,2,3,
@@ -80,7 +80,7 @@ var dataset = [
             {
                 "columns": 4,
                 "image":
-                [
+                    [
                     4,4,4,4,
                     0,2,2,2,
                     0,3,3,0,
@@ -91,7 +91,7 @@ var dataset = [
             {
                 "columns": 6,
                 "image":
-                [
+                    [
                     1,1,1,1,1,1,
                     1,2,0,0,0,1,
                     1,0,2,3,0,1,
@@ -103,7 +103,7 @@ var dataset = [
             {
                 "columns": 6,
                 "image":
-                [
+                    [
                     1,2,2,2,2,2,
                     3,1,0,0,0,2,
                     3,0,1,4,0,2,
@@ -115,7 +115,7 @@ var dataset = [
             {
                 "columns": 6,
                 "image":
-                [
+                    [
                     1,2,2,2,2,3,
                     4,0,0,0,0,4,
                     4,0,0,0,0,4,
@@ -127,7 +127,7 @@ var dataset = [
             {
                 "columns": 7,
                 "image":
-                [
+                    [
                     0,1,1,1,1,1,0,
                     1,0,0,0,0,0,1,
                     1,0,3,0,2,0,1,
@@ -140,7 +140,7 @@ var dataset = [
             {
                 "columns": 7,
                 "image":
-                [
+                    [
                     1,0,1,0,1,0,1,
                     0,2,0,2,0,2,0,
                     3,0,3,0,3,0,3,
@@ -151,293 +151,316 @@ var dataset = [
                 ]
             },
             { // A
-                "columns": 4,
+                "columns": 6,
                 "image":
-                [
-                    0,2,2,0,
-                    2,0,0,2,
-                    2,1,3,2,
-                    2,0,0,2,
-                    2,0,0,2
+                    [
+                    0,2,2,0,1,2,
+                    2,0,0,2,3,2,
+                    2,1,3,2,0,1,
+                    2,0,0,2,4,0,
+                    2,0,0,2,0,4
                 ]
             },
             { // B
-                "columns": 4,
+                "columns": 7,
                 "image":
-                [
-                    2,2,2,2,
-                    2,0,0,2,
-                    2,1,1,0,
-                    2,0,0,2,
-                    2,2,2,2
+                    [
+                    2,2,2,2,1,1,1,
+                    2,0,0,2,3,0,1,
+                    2,1,1,0,1,0,2,
+                    2,0,0,2,3,4,1,
+                    2,2,2,2,4,3,1
                 ]
             },
             { // C
-                "columns": 4,
+                "columns": 6,
                 "image":
-                [
-                    2,3,3,3,
-                    2,0,0,0,
-                    2,0,0,0,
-                    2,0,0,0,
-                    2,3,3,3
+                    [
+                    2,3,3,3,4,5,
+                    2,0,0,0,0,6,
+                    2,0,2,0,3,2,
+                    2,0,1,0,2,1,
+                    2,3,3,3,2,5
                 ]
             },
             { // D
-                "columns": 4,
+                "columns": 6,
                 "image":
-                [
-                    1,1,1,0,
-                    1,0,0,2,
-                    1,0,0,2,
-                    1,0,0,2,
-                    1,1,1,0
+                    [
+                    1,1,1,0,1,0,
+                    1,0,0,2,3,4,
+                    1,0,4,2,4,3,
+                    1,0,0,2,5,0,
+                    1,1,1,0,3,1
                 ]
             },
             { // E
-                "columns": 4,
+                "columns": 6,
                 "image":
-                [
-                    1,1,1,1,
-                    1,0,0,0,
-                    1,2,2,0,
-                    1,0,0,0,
-                    1,1,1,1,
+                    [
+                    1,1,1,1,1,1,
+                    1,0,2,0,1,0,
+                    1,2,2,0,3,3,
+                    1,0,3,0,4,0,
+                    1,1,1,1,0,0
                 ]
             },
             { // F
-                "columns": 4,
+                "columns": 6,
                 "image":
-                [
-                    1,1,1,1,
-                    1,0,0,0,
-                    1,2,2,0,
-                    1,0,0,0,
-                    1,0,0,0
+                    [
+                    1,2,1,3,1,4,
+                    1,0,2,0,3,0,
+                    4,2,2,0,4,4,
+                    1,0,3,0,3,0,
+                    1,2,0,0,2,1,
+                    2,5,0,0,1,2
                 ]
             },
             { // G
-                "columns": 4,
+                "columns": 7,
                 "image":
-                [
-                    1,1,1,1,
-                    1,0,0,0,
-                    1,0,2,2,
-                    1,0,0,2,
-                    1,1,1,1
+                    [
+                    1,2,1,3,1,4,1,
+                    1,0,2,0,3,0,5,
+                    1,0,2,2,0,3,3,
+                    1,0,0,2,2,0,3,
+                    1,6,1,0,4,2,1
                 ]
             },
             { // H
-                "columns": 4,
+                "columns": 6,
                 "image":
-                [
-                    1,0,0,1,
-                    1,0,0,1,
-                    1,2,3,1,
-                    1,0,0,1,
-                    1,0,0,1
+                    [
+                    4,0,2,1,3,5,
+                    1,2,0,3,4,1,
+                    1,2,3,1,2,1,
+                    1,0,5,5,0,1,
+                    1,0,6,1,6,0
                 ]
             },
             { // I
-                "columns": 4,
+                "columns": 7,
                 "image":
-                [
-                    0,2,2,2,
-                    0,0,1,0,
-                    0,0,1,0,
-                    0,0,1,0,
-                    0,2,2,2
+                    [
+                    0,2,2,2,2,0,5,
+                    2,0,1,0,3,1,4,
+                    4,0,1,0,5,6,0,
+                    4,0,1,2,3,4,6,
+                    0,2,2,2,0,0,5
                 ]
             },
             { // J
-                "columns": 4,
+                "columns": 7,
                 "image":
-                [
-                    0,1,1,1,
-                    0,0,2,0,
-                    0,0,2,0,
-                    1,0,2,0,
-                    1,1,1,0
+                    [
+                    0,3,2,4,0,1,1,
+                    0,3,2,0,1,4,2,
+                    0,0,2,0,4,5,1,
+                    1,0,2,0,0,0,1,
+                    1,2,1,0,4,1,3
                 ]
             },
             { // K
-                "columns": 4,
+                "columns": 7,
                 "image":
-                [
-                    1,0,0,1,
-                    1,0,2,0,
-                    1,2,0,0,
-                    1,0,2,0,
-                    1,0,0,1
+                    [
+                    1,4,0,1,2,0,0,
+                    1,0,5,0,0,3,0,
+                    1,3,0,0,0,0,4,
+                    1,0,5,0,0,3,0,
+                    1,4,0,1,2,0,0
                 ]
             },
             { // L
-                "columns": 4,
+                "columns": 7,
                 "image":
-                [
-                    1,0,0,0,
-                    1,0,0,0,
-                    1,0,0,0,
-                    1,0,0,0,
-                    2,2,2,2
+                    [
+                    1,0,0,0,3,0,0,
+                    1,0,0,3,0,3,0,
+                    1,0,3,0,4,0,3,
+                    1,3,0,0,0,3,4,
+                    2,2,2,2,2,2,2
                 ]
             },
             { // M
-                "columns": 5,
+                "columns": 7,
                 "image":
-                [
-                    1,0,0,0,1,
-                    1,2,0,2,1,
-                    1,0,2,0,1,
-                    1,0,0,0,1,
-                    1,0,0,0,1
+                    [
+                    1,0,0,0,1,4,0,
+                    1,2,0,2,1,0,5,
+                    1,0,2,0,1,4,0,
+                    1,0,3,0,1,0,5,
+                    1,3,0,3,1,4,0,
+                    0,1,0,5,0,1,0
                 ]
             },
             { // N
-                "columns": 5,
+                "columns": 7,
                 "image":
-                [
-                    1,0,0,0,1,
-                    1,2,0,0,1,
-                    1,0,2,0,1,
-                    1,0,0,2,1,
-                    1,0,0,0,1
+                    [
+                    1,0,5,0,1,0,0,
+                    1,2,0,4,0,5,0,
+                    1,0,2,0,1,0,1,
+                    1,4,0,2,0,4,0,
+                    1,0,5,0,1,0,1,
+                    0,0,1,0,5,0,1
                 ]
             },
             { // O
-                "columns": 4,
+                "columns": 7,
                 "image":
-                [
-                    0,2,3,0,
-                    1,0,0,1,
-                    1,0,0,1,
-                    1,0,0,1,
-                    0,3,2,0
+                    [
+                    0,2,3,0,3,2,0,
+                    1,5,0,1,0,1,1,
+                    1,0,5,1,1,0,1,
+                    1,5,0,1,0,1,1,
+                    0,3,2,0,2,3,0,
+                    1,2,0,1,0,5,1,
+                    0,3,2,0,2,3,0
                 ]
             },
             { // P
-                "columns": 4,
+                "columns": 8,
                 "image":
-                [
-                    1,1,1,1,
-                    1,0,0,1,
-                    1,2,2,1,
-                    1,0,0,0,
-                    1,0,0,0
+                    [
+                    1,3,3,1,1,2,2,1,
+                    2,0,5,1,5,0,0,2,
+                    1,2,2,1,4,5,5,4,
+                    1,0,4,0,5,0,4,2,
+                    1,5,0,4,4,0,5,1,
+                    0,1,1,0,0,1,1,0,
+                    3,4,0,2,2,0,4,3
                 ]
             },
             { // Q
-                "columns": 4,
+                "columns": 8,
                 "image":
-                [
-                    0,1,1,0,
-                    1,0,0,1,
-                    1,0,0,1,
-                    1,0,0,1,
-                    0,1,1,0,
-                    0,0,0,2,
+                    [
+                    0,3,3,0,0,2,2,0,
+                    4,0,0,4,4,0,0,4,
+                    1,0,0,4,4,0,0,4,
+                    2,4,0,0,3,0,4,2,
+                    1,5,0,3,1,0,5,1,
+                    0,0,0,4,4,0,0,0,
+                    4,3,5,1,1,5,4,3
                 ]
             },
             { // R
-                "columns": 5,
+                "columns": 8,
                 "image":
-                [
-                    1,1,1,1,0,
-                    1,0,0,0,1,
-                    1,0,0,0,1,
-                    1,1,1,1,0,
-                    1,0,0,2,0,
-                    1,0,0,0,2
+                    [
+                    5,0,0,0,5,0,0,0,
+                    0,4,0,4,0,4,0,4,
+                    0,0,3,0,0,0,3,0,
+                    0,0,1,0,0,0,1,0,
+                    0,1,0,1,0,1,0,1,
+                    1,0,0,0,1,0,0,0,
+                    2,0,2,0,2,0,2,0
                 ]
             },
             { // S
-                "columns": 6,
+                "columns": 8,
                 "image":
-                [
-                    1,1,1,1,1,1,
-                    2,0,0,0,0,1,
-                    0,2,2,0,0,0,
-                    0,0,0,2,2,0,
-                    1,0,0,0,0,2,
-                    1,1,1,1,1,1
+                    [
+                    1,0,2,3,0,2,0,1,
+                    0,2,0,4,4,0,2,0,
+                    0,0,3,0,0,3,0,0,
+                    0,0,0,4,4,0,0,0,
+                    0,0,3,0,0,3,0,0,
+                    0,2,0,4,4,0,2,0,
+                    1,0,2,0,3,2,0,1
                 ]
             },
             { // T
-                "columns": 5,
+                "columns": 8,
                 "image":
-                [
-                    1,1,1,1,1,
-                    0,0,2,0,0,
-                    0,0,2,0,0,
-                    0,0,2,0,0,
-                    0,0,2,0,0
+                    [
+                    4,0,4,0,4,0,4,0,
+                    0,5,0,5,0,5,0,5,
+                    4,0,4,0,4,0,4,0,
+                    0,5,0,5,0,5,0,5,
+                    4,0,4,0,4,0,4,0,
+                    0,5,0,5,0,5,0,5,
+                    4,0,4,0,4,0,4,0
                 ]
             },
             { // U
-                "columns": 4,
+                "columns": 8,
                 "image":
-                [
-                    1,0,0,1,
-                    1,0,0,1,
-                    1,0,0,1,
-                    1,0,0,1,
-                    2,1,1,3
+                    [
+                    4,0,1,0,4,0,1,0,
+                    0,5,0,3,3,0,0,5,
+                    4,0,2,0,0,0,3,0,
+                    0,5,0,3,0,3,0,5,
+                    4,0,3,4,4,0,2,0,
+                    0,5,0,1,3,2,0,5,
+                    4,0,1,2,4,0,1,0
                 ]
             },
             { // V
-                "columns": 5,
+                "columns": 8,
                 "image":
-                [
-                    1,0,0,0,1,
-                    1,0,0,0,1,
-                    0,2,0,3,0,
-                    0,2,0,3,0,
-                    0,0,1,0,0,
+                    [
+                    0,3,3,0,0,3,3,0,
+                    5,0,0,5,5,0,0,5,
+                    4,0,0,4,4,0,0,4,
+                    0,5,5,0,0,5,5,0,
+                    3,0,4,0,3,0,4,0,
+                    0,2,0,2,0,2,0,2,
+                    4,0,1,0,4,0,1,0
                 ]
             },
             { // W
-                "columns": 7,
+                "columns": 8,
                 "image":
-                [
-                    1,0,0,0,0,0,1,
-                    1,0,0,0,0,0,1,
-                    1,1,0,0,0,1,1,
-                    0,1,0,0,0,1,0,
-                    0,1,0,1,0,1,0,
-                    0,0,2,0,3,0,0
+                    [
+                    1,0,2,0,5,2,0,3,
+                    0,2,0,1,0,4,0,0,
+                    0,0,3,0,1,0,3,0,
+                    0,5,0,4,0,5,0,1,
+                    0,1,1,0,5,0,4,0,
+                    0,1,0,2,0,4,0,3,
+                    0,2,0,1,0,3,0,4
                 ]
             },
             { // X
-                "columns": 5,
+                "columns": 8,
                 "image":
-                [
-                    1,0,0,0,1,
-                    0,2,0,3,0,
-                    0,0,1,0,0,
-                    0,3,0,2,0,
-                    1,0,0,0,1
+                    [
+                    0,1,3,0,2,1,0,3,
+                    0,4,1,0,0,4,1,0,
+                    5,3,0,0,1,0,3,5,
+                    4,1,0,4,1,0,4,1,
+                    0,1,1,0,5,0,4,0,
+                    0,1,0,2,0,4,0,3,
+                    0,2,0,1,1,0,0,4
                 ]
             },
             { // Y
-                "columns": 5,
+                "columns": 8,
                 "image":
-                [
-                    1,0,0,0,3,
-                    0,1,0,3,0,
-                    0,0,2,0,0,
-                    0,0,2,0,0,
-                    0,0,2,0,0
+                    [
+                    1,0,1,0,1,0,1,0,
+                    0,2,0,2,0,2,0,2,
+                    3,0,3,0,3,0,3,0,
+                    0,4,0,4,0,4,0,4,
+                    1,0,1,0,1,0,1,0,
+                    0,2,0,2,0,2,0,2,
+                    3,0,3,0,3,0,3,0
                 ]
             },
             { // Z
-                "columns": 5,
+                "columns": 8,
                 "image":
-                [
-                    1,1,1,1,1,
-                    0,0,0,2,0,
-                    0,0,2,0,0,
-                    0,2,0,0,0,
-                    1,1,1,1,1
+                    [
+                    1,5,1,0,1,5,1,0,
+                    0,2,0,2,0,2,0,2,
+                    3,0,3,1,3,1,3,0,
+                    0,4,0,5,5,0,0,4,
+                    1,0,1,4,4,0,1,0,
+                    0,2,0,2,2,0,0,2,
+                    3,0,3,0,3,0,3,0
                 ]
             },
         ]
