@@ -24,6 +24,7 @@
 
 #include "ApplicationInfo.h"
 
+#include <QtQml>
 #include <QtMath>
 #include <QUrl>
 #include <QUrlQuery>
@@ -85,10 +86,12 @@ ApplicationInfo::ApplicationInfo(QObject *parent): QObject(parent)
     if (m_isMobile)
         connect(qApp->primaryScreen(), &QScreen::physicalSizeChanged, this, &ApplicationInfo::notifyPortraitMode);
 
+// @FIXME this does not work on iOS: https://bugreports.qt.io/browse/QTBUG-50624
+#if not defined(Q_OS_IOS)
     // Get all symbol fonts to remove them
     QFontDatabase database;
     m_excludedFonts = database.families(QFontDatabase::Symbol);
-
+#endif
     // Get fonts from rcc
     const QStringList fontFilters = {"*.otf", "*.ttf"};
     m_fontsFromRcc = QDir(":/gcompris/src/core/resource/fonts").entryList(fontFilters);
@@ -127,8 +130,10 @@ QString ApplicationInfo::getFilePath(const QString &file)
 {
 #if defined(Q_OS_ANDROID)
     return QString("assets:/%1").arg(file);
-#elif defined(Q_OS_MAC)
+#elif defined(Q_OS_MACX)
     return QString("%1/../Resources/rcc/%2").arg(QCoreApplication::applicationDirPath(), file);
+#elif defined(Q_OS_IOS)
+    return QString("%1/rcc/%2").arg(QCoreApplication::applicationDirPath(), file);
 #else
     return QString("%1/%2/rcc/%3").arg(QCoreApplication::applicationDirPath(), GCOMPRIS_DATA_FOLDER, file);
 #endif
@@ -231,6 +236,18 @@ QString ApplicationInfo::getVoicesLocale(const QString &locale)
     return localeShort(_locale);
 }
 
+QVariantList ApplicationInfo::localeSort(QVariantList list,
+                                         const QString& locale) const
+{
+    QElapsedTimer timer;
+    timer.start();
+    std::sort(list.begin(), list.end(),
+              [&locale,this](const QVariant& a, const QVariant& b) {
+        return (localeCompare(a.toString(), b.toString(), locale) < 0);
+    });
+    return list;
+}
+
 QObject *ApplicationInfo::systeminfoProvider(QQmlEngine *engine,
                                              QJSEngine *scriptEngine)
 {
