@@ -12,6 +12,7 @@ fi
 
 # The current version
 version=$(sed -n -e 's/set(GCOMPRIS_MINOR_VERSION \([0-9]\+\)).*/\1/p' CMakeLists.txt)
+curbranch=$(git rev-parse --abbrev-ref HEAD)
 
 # Uncomment if this is not already done
 git checkout -b 0.${version}-po
@@ -22,5 +23,5 @@ make getSvnTranslations
 git add -f ../po
 git commit -a -m "PO INTEGRATED / DO NOT PUSH ME"
 make dist
-git checkout 0.${version}
+git checkout ${curbranch}
 git branch -D 0.${version}-po
